# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/inter_container.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import voltha_pb2 as voltha__protos_dot_voltha__pb2
try:
  voltha__protos_dot_meta__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_meta__pb2
except AttributeError:
  voltha__protos_dot_meta__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.meta_pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.common_pb2
try:
  voltha__protos_dot_health__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_health__pb2
except AttributeError:
  voltha__protos_dot_health__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.health_pb2
try:
  voltha__protos_dot_logical__device__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_logical__device__pb2
except AttributeError:
  voltha__protos_dot_logical__device__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.logical_device_pb2
try:
  voltha__protos_dot_device__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_device__pb2
except AttributeError:
  voltha__protos_dot_device__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.device_pb2
try:
  voltha__protos_dot_adapter__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_adapter__pb2
except AttributeError:
  voltha__protos_dot_adapter__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.adapter_pb2
try:
  voltha__protos_dot_openflow__13__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_openflow__13__pb2
except AttributeError:
  voltha__protos_dot_openflow__13__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.openflow_13_pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2
from voltha_protos import logical_device_pb2 as voltha__protos_dot_logical__device__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from voltha_protos.common_pb2 import *
from voltha_protos.voltha_pb2 import *
from voltha_protos.logical_device_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/inter_container.proto',
  package='voltha',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaZ7github.com/opencord/voltha-protos/v3/go/inter_container',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#voltha_protos/inter_container.proto\x12\x06voltha\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/voltha.proto\x1a\x19google/protobuf/any.proto\x1a\x1fvoltha_protos/openflow_13.proto\x1a\"voltha_protos/logical_device.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x16\n\x07StrType\x12\x0b\n\x03val\x18\x01 \x01(\t\"\x16\n\x07IntType\x12\x0b\n\x03val\x18\x01 \x01(\x03\"\x17\n\x08\x42oolType\x12\x0b\n\x03val\x18\x01 \x01(\x08\"\x19\n\x06Packet\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\"\\\n\tErrorCode\"O\n\x05\x63odes\x12\x17\n\x13UNSUPPORTED_REQUEST\x10\x00\x12\x16\n\x12INVALID_PARAMETERS\x10\x01\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x02\">\n\x05\x45rror\x12%\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x17.voltha.ErrorCode.codes\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x9f\x01\n\x06Header\x12\n\n\x02id\x18\x01 \x01(\t\x12!\n\x04type\x18\x02 \x01(\x0e\x32\x13.voltha.MessageType\x12\x12\n\nfrom_topic\x18\x03 \x01(\t\x12\x10\n\x08to_topic\x18\x04 \x01(\t\x12\x11\n\tkey_topic\x18\x05 \x01(\t\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"<\n\x08\x41rgument\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"[\n\x15InterContainerMessage\x12\x1e\n\x06header\x18\x01 \x01(\x0b\x32\x0e.voltha.Header\x12\"\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"{\n\x19InterContainerRequestBody\x12\x0b\n\x03rpc\x18\x02 \x01(\t\x12\x1e\n\x04\x61rgs\x18\x03 \x03(\x0b\x32\x10.voltha.Argument\x12\x19\n\x11response_required\x18\x04 \x01(\x08\x12\x16\n\x0ereply_to_topic\x18\x05 \x01(\t\"S\n\x1aInterContainerResponseBody\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12$\n\x06result\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"r\n\x10SwitchCapability\x12#\n\x04\x64\x65sc\x18\x01 \x01(\x0b\x32\x15.openflow_13.ofp_desc\x12\x39\n\x0fswitch_features\x18\x02 \x01(\x0b\x32 .openflow_13.ofp_switch_features\"Y\n\x10\x44\x65viceDiscovered\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x03 \x01(\t\x12\x11\n\tpublisher\x18\x04 \x01(\t\"\x9d\x02\n\x17InterAdapterMessageType\"\x81\x02\n\x05Types\x12\x10\n\x0c\x46LOW_REQUEST\x10\x00\x12\x11\n\rFLOW_RESPONSE\x10\x01\x12\x10\n\x0cOMCI_REQUEST\x10\x02\x12\x11\n\rOMCI_RESPONSE\x10\x03\x12\x13\n\x0fMETRICS_REQUEST\x10\x04\x12\x14\n\x10METRICS_RESPONSE\x10\x05\x12\x13\n\x0fONU_IND_REQUEST\x10\x06\x12\x14\n\x10ONU_IND_RESPONSE\x10\x07\x12!\n\x1dTECH_PROFILE_DOWNLOAD_REQUEST\x10\x08\x12\x1b\n\x17\x44\x45LETE_GEM_PORT_REQUEST\x10\t\x12\x18\n\x14\x44\x45LETE_TCONT_REQUEST\x10\n\"\xd9\x01\n\x12InterAdapterHeader\x12\n\n\x02id\x18\x01 \x01(\t\x12\x33\n\x04type\x18\x02 \x01(\x0e\x32%.voltha.InterAdapterMessageType.Types\x12\x12\n\nfrom_topic\x18\x03 \x01(\t\x12\x10\n\x08to_topic\x18\x04 \x01(\t\x12\x14\n\x0cto_device_id\x18\x05 \x01(\t\x12\x17\n\x0fproxy_device_id\x18\x06 \x01(\t\x12-\n\ttimestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x93\x01\n\x17InterAdapterOmciMessage\x12\x0f\n\x07message\x18\x01 \x01(\x0c\x12\x33\n\x0e\x63onnect_status\x18\x02 \x01(\x0e\x32\x1b.common.ConnectStatus.Types\x12\x32\n\rproxy_address\x18\x03 \x01(\x0b\x32\x1b.voltha.Device.ProxyAddress\"F\n&InterAdapterTechProfileDownloadMessage\x12\x0e\n\x06uni_id\x18\x01 \x01(\r\x12\x0c\n\x04path\x18\x02 \x01(\t\"X\n InterAdapterDeleteGemPortMessage\x12\x0e\n\x06uni_id\x18\x01 \x01(\r\x12\x0f\n\x07tp_path\x18\x02 \x01(\t\x12\x13\n\x0bgem_port_id\x18\x03 \x01(\r\"S\n\x1eInterAdapterDeleteTcontMessage\x12\x0e\n\x06uni_id\x18\x01 \x01(\r\x12\x0f\n\x07tp_path\x18\x02 \x01(\t\x12\x10\n\x08\x61lloc_id\x18\x03 \x01(\r\"\x8c\x01\n\x18InterAdapterResponseBody\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12$\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12/\n\x04omci\x18\x03 \x01(\x0b\x32\x1f.voltha.InterAdapterOmciMessageH\x00\x42\t\n\x07payload\"e\n\x13InterAdapterMessage\x12*\n\x06header\x18\x01 \x01(\x0b\x32\x1a.voltha.InterAdapterHeader\x12\"\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any*?\n\x0bMessageType\x12\x0b\n\x07REQUEST\x10\x00\x12\x0c\n\x08RESPONSE\x10\x01\x12\x15\n\x11\x44\x45VICE_DISCOVERED\x10\x02\x42N\n\x13org.opencord.volthaZ7github.com/opencord/voltha-protos/v3/go/inter_containerP\x00P\x01P\x04\x62\x06proto3'
  ,
  dependencies=[voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_voltha__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,voltha__protos_dot_openflow__13__pb2.DESCRIPTOR,voltha__protos_dot_logical__device__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,],
  public_dependencies=[voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_voltha__pb2.DESCRIPTOR,voltha__protos_dot_logical__device__pb2.DESCRIPTOR,])

_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='voltha.MessageType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REQUEST', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESPONSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_DISCOVERED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2375,
  serialized_end=2438,
)
_sym_db.RegisterEnumDescriptor(_MESSAGETYPE)

MessageType = enum_type_wrapper.EnumTypeWrapper(_MESSAGETYPE)
REQUEST = 0
RESPONSE = 1
DEVICE_DISCOVERED = 2


_ERRORCODE_CODES = _descriptor.EnumDescriptor(
  name='codes',
  full_name='voltha.ErrorCode.codes',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_REQUEST', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PARAMETERS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEADLINE_EXCEEDED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=345,
  serialized_end=424,
)
_sym_db.RegisterEnumDescriptor(_ERRORCODE_CODES)

_INTERADAPTERMESSAGETYPE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='voltha.InterAdapterMessageType.Types',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FLOW_REQUEST', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOW_RESPONSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OMCI_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OMCI_RESPONSE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='METRICS_REQUEST', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='METRICS_RESPONSE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONU_IND_REQUEST', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONU_IND_RESPONSE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TECH_PROFILE_DOWNLOAD_REQUEST', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETE_GEM_PORT_REQUEST', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETE_TCONT_REQUEST', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1253,
  serialized_end=1510,
)
_sym_db.RegisterEnumDescriptor(_INTERADAPTERMESSAGETYPE_TYPES)


_STRTYPE = _descriptor.Descriptor(
  name='StrType',
  full_name='voltha.StrType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='voltha.StrType.val', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=254,
)


_INTTYPE = _descriptor.Descriptor(
  name='IntType',
  full_name='voltha.IntType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='voltha.IntType.val', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=278,
)


_BOOLTYPE = _descriptor.Descriptor(
  name='BoolType',
  full_name='voltha.BoolType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='voltha.BoolType.val', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=303,
)


_PACKET = _descriptor.Descriptor(
  name='Packet',
  full_name='voltha.Packet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='voltha.Packet.payload', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=330,
)


_ERRORCODE = _descriptor.Descriptor(
  name='ErrorCode',
  full_name='voltha.ErrorCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ERRORCODE_CODES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=424,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='voltha.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='voltha.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='voltha.Error.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=488,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='voltha.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.Header.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.Header.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_topic', full_name='voltha.Header.from_topic', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_topic', full_name='voltha.Header.to_topic', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_topic', full_name='voltha.Header.key_topic', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='voltha.Header.timestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=650,
)


_ARGUMENT = _descriptor.Descriptor(
  name='Argument',
  full_name='voltha.Argument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.Argument.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.Argument.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=712,
)


_INTERCONTAINERMESSAGE = _descriptor.Descriptor(
  name='InterContainerMessage',
  full_name='voltha.InterContainerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='voltha.InterContainerMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='voltha.InterContainerMessage.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=714,
  serialized_end=805,
)


_INTERCONTAINERREQUESTBODY = _descriptor.Descriptor(
  name='InterContainerRequestBody',
  full_name='voltha.InterContainerRequestBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rpc', full_name='voltha.InterContainerRequestBody.rpc', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='voltha.InterContainerRequestBody.args', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_required', full_name='voltha.InterContainerRequestBody.response_required', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_to_topic', full_name='voltha.InterContainerRequestBody.reply_to_topic', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=930,
)


_INTERCONTAINERRESPONSEBODY = _descriptor.Descriptor(
  name='InterContainerResponseBody',
  full_name='voltha.InterContainerResponseBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='voltha.InterContainerResponseBody.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='voltha.InterContainerResponseBody.result', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=1015,
)


_SWITCHCAPABILITY = _descriptor.Descriptor(
  name='SwitchCapability',
  full_name='voltha.SwitchCapability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='voltha.SwitchCapability.desc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='switch_features', full_name='voltha.SwitchCapability.switch_features', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1017,
  serialized_end=1131,
)


_DEVICEDISCOVERED = _descriptor.Descriptor(
  name='DeviceDiscovered',
  full_name='voltha.DeviceDiscovered',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.DeviceDiscovered.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='voltha.DeviceDiscovered.parent_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_type', full_name='voltha.DeviceDiscovered.device_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publisher', full_name='voltha.DeviceDiscovered.publisher', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1133,
  serialized_end=1222,
)


_INTERADAPTERMESSAGETYPE = _descriptor.Descriptor(
  name='InterAdapterMessageType',
  full_name='voltha.InterAdapterMessageType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INTERADAPTERMESSAGETYPE_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1225,
  serialized_end=1510,
)


_INTERADAPTERHEADER = _descriptor.Descriptor(
  name='InterAdapterHeader',
  full_name='voltha.InterAdapterHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.InterAdapterHeader.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.InterAdapterHeader.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_topic', full_name='voltha.InterAdapterHeader.from_topic', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_topic', full_name='voltha.InterAdapterHeader.to_topic', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_device_id', full_name='voltha.InterAdapterHeader.to_device_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy_device_id', full_name='voltha.InterAdapterHeader.proxy_device_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='voltha.InterAdapterHeader.timestamp', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1513,
  serialized_end=1730,
)


_INTERADAPTEROMCIMESSAGE = _descriptor.Descriptor(
  name='InterAdapterOmciMessage',
  full_name='voltha.InterAdapterOmciMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='voltha.InterAdapterOmciMessage.message', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_status', full_name='voltha.InterAdapterOmciMessage.connect_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy_address', full_name='voltha.InterAdapterOmciMessage.proxy_address', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1733,
  serialized_end=1880,
)


_INTERADAPTERTECHPROFILEDOWNLOADMESSAGE = _descriptor.Descriptor(
  name='InterAdapterTechProfileDownloadMessage',
  full_name='voltha.InterAdapterTechProfileDownloadMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='voltha.InterAdapterTechProfileDownloadMessage.uni_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='voltha.InterAdapterTechProfileDownloadMessage.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1882,
  serialized_end=1952,
)


_INTERADAPTERDELETEGEMPORTMESSAGE = _descriptor.Descriptor(
  name='InterAdapterDeleteGemPortMessage',
  full_name='voltha.InterAdapterDeleteGemPortMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='voltha.InterAdapterDeleteGemPortMessage.uni_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tp_path', full_name='voltha.InterAdapterDeleteGemPortMessage.tp_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gem_port_id', full_name='voltha.InterAdapterDeleteGemPortMessage.gem_port_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1954,
  serialized_end=2042,
)


_INTERADAPTERDELETETCONTMESSAGE = _descriptor.Descriptor(
  name='InterAdapterDeleteTcontMessage',
  full_name='voltha.InterAdapterDeleteTcontMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='voltha.InterAdapterDeleteTcontMessage.uni_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tp_path', full_name='voltha.InterAdapterDeleteTcontMessage.tp_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alloc_id', full_name='voltha.InterAdapterDeleteTcontMessage.alloc_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2044,
  serialized_end=2127,
)


_INTERADAPTERRESPONSEBODY = _descriptor.Descriptor(
  name='InterAdapterResponseBody',
  full_name='voltha.InterAdapterResponseBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='voltha.InterAdapterResponseBody.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='voltha.InterAdapterResponseBody.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omci', full_name='voltha.InterAdapterResponseBody.omci', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='voltha.InterAdapterResponseBody.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2130,
  serialized_end=2270,
)


_INTERADAPTERMESSAGE = _descriptor.Descriptor(
  name='InterAdapterMessage',
  full_name='voltha.InterAdapterMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='voltha.InterAdapterMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='voltha.InterAdapterMessage.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2272,
  serialized_end=2373,
)

_ERRORCODE_CODES.containing_type = _ERRORCODE
_ERROR.fields_by_name['code'].enum_type = _ERRORCODE_CODES
_HEADER.fields_by_name['type'].enum_type = _MESSAGETYPE
_HEADER.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ARGUMENT.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INTERCONTAINERMESSAGE.fields_by_name['header'].message_type = _HEADER
_INTERCONTAINERMESSAGE.fields_by_name['body'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INTERCONTAINERREQUESTBODY.fields_by_name['args'].message_type = _ARGUMENT
_INTERCONTAINERRESPONSEBODY.fields_by_name['result'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SWITCHCAPABILITY.fields_by_name['desc'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_DESC
_SWITCHCAPABILITY.fields_by_name['switch_features'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_SWITCH_FEATURES
_INTERADAPTERMESSAGETYPE_TYPES.containing_type = _INTERADAPTERMESSAGETYPE
_INTERADAPTERHEADER.fields_by_name['type'].enum_type = _INTERADAPTERMESSAGETYPE_TYPES
_INTERADAPTERHEADER.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INTERADAPTEROMCIMESSAGE.fields_by_name['connect_status'].enum_type = voltha__protos_dot_common__pb2._CONNECTSTATUS_TYPES
_INTERADAPTEROMCIMESSAGE.fields_by_name['proxy_address'].message_type = voltha__protos_dot_device__pb2._DEVICE_PROXYADDRESS
_INTERADAPTERRESPONSEBODY.fields_by_name['body'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INTERADAPTERRESPONSEBODY.fields_by_name['omci'].message_type = _INTERADAPTEROMCIMESSAGE
_INTERADAPTERRESPONSEBODY.oneofs_by_name['payload'].fields.append(
  _INTERADAPTERRESPONSEBODY.fields_by_name['body'])
_INTERADAPTERRESPONSEBODY.fields_by_name['body'].containing_oneof = _INTERADAPTERRESPONSEBODY.oneofs_by_name['payload']
_INTERADAPTERRESPONSEBODY.oneofs_by_name['payload'].fields.append(
  _INTERADAPTERRESPONSEBODY.fields_by_name['omci'])
_INTERADAPTERRESPONSEBODY.fields_by_name['omci'].containing_oneof = _INTERADAPTERRESPONSEBODY.oneofs_by_name['payload']
_INTERADAPTERMESSAGE.fields_by_name['header'].message_type = _INTERADAPTERHEADER
_INTERADAPTERMESSAGE.fields_by_name['body'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['StrType'] = _STRTYPE
DESCRIPTOR.message_types_by_name['IntType'] = _INTTYPE
DESCRIPTOR.message_types_by_name['BoolType'] = _BOOLTYPE
DESCRIPTOR.message_types_by_name['Packet'] = _PACKET
DESCRIPTOR.message_types_by_name['ErrorCode'] = _ERRORCODE
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Argument'] = _ARGUMENT
DESCRIPTOR.message_types_by_name['InterContainerMessage'] = _INTERCONTAINERMESSAGE
DESCRIPTOR.message_types_by_name['InterContainerRequestBody'] = _INTERCONTAINERREQUESTBODY
DESCRIPTOR.message_types_by_name['InterContainerResponseBody'] = _INTERCONTAINERRESPONSEBODY
DESCRIPTOR.message_types_by_name['SwitchCapability'] = _SWITCHCAPABILITY
DESCRIPTOR.message_types_by_name['DeviceDiscovered'] = _DEVICEDISCOVERED
DESCRIPTOR.message_types_by_name['InterAdapterMessageType'] = _INTERADAPTERMESSAGETYPE
DESCRIPTOR.message_types_by_name['InterAdapterHeader'] = _INTERADAPTERHEADER
DESCRIPTOR.message_types_by_name['InterAdapterOmciMessage'] = _INTERADAPTEROMCIMESSAGE
DESCRIPTOR.message_types_by_name['InterAdapterTechProfileDownloadMessage'] = _INTERADAPTERTECHPROFILEDOWNLOADMESSAGE
DESCRIPTOR.message_types_by_name['InterAdapterDeleteGemPortMessage'] = _INTERADAPTERDELETEGEMPORTMESSAGE
DESCRIPTOR.message_types_by_name['InterAdapterDeleteTcontMessage'] = _INTERADAPTERDELETETCONTMESSAGE
DESCRIPTOR.message_types_by_name['InterAdapterResponseBody'] = _INTERADAPTERRESPONSEBODY
DESCRIPTOR.message_types_by_name['InterAdapterMessage'] = _INTERADAPTERMESSAGE
DESCRIPTOR.enum_types_by_name['MessageType'] = _MESSAGETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StrType = _reflection.GeneratedProtocolMessageType('StrType', (_message.Message,), {
  'DESCRIPTOR' : _STRTYPE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.StrType)
  })
_sym_db.RegisterMessage(StrType)

IntType = _reflection.GeneratedProtocolMessageType('IntType', (_message.Message,), {
  'DESCRIPTOR' : _INTTYPE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.IntType)
  })
_sym_db.RegisterMessage(IntType)

BoolType = _reflection.GeneratedProtocolMessageType('BoolType', (_message.Message,), {
  'DESCRIPTOR' : _BOOLTYPE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.BoolType)
  })
_sym_db.RegisterMessage(BoolType)

Packet = _reflection.GeneratedProtocolMessageType('Packet', (_message.Message,), {
  'DESCRIPTOR' : _PACKET,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Packet)
  })
_sym_db.RegisterMessage(Packet)

ErrorCode = _reflection.GeneratedProtocolMessageType('ErrorCode', (_message.Message,), {
  'DESCRIPTOR' : _ERRORCODE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.ErrorCode)
  })
_sym_db.RegisterMessage(ErrorCode)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
  'DESCRIPTOR' : _ERROR,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Error)
  })
_sym_db.RegisterMessage(Error)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
  'DESCRIPTOR' : _HEADER,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Header)
  })
_sym_db.RegisterMessage(Header)

Argument = _reflection.GeneratedProtocolMessageType('Argument', (_message.Message,), {
  'DESCRIPTOR' : _ARGUMENT,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Argument)
  })
_sym_db.RegisterMessage(Argument)

InterContainerMessage = _reflection.GeneratedProtocolMessageType('InterContainerMessage', (_message.Message,), {
  'DESCRIPTOR' : _INTERCONTAINERMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterContainerMessage)
  })
_sym_db.RegisterMessage(InterContainerMessage)

InterContainerRequestBody = _reflection.GeneratedProtocolMessageType('InterContainerRequestBody', (_message.Message,), {
  'DESCRIPTOR' : _INTERCONTAINERREQUESTBODY,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterContainerRequestBody)
  })
_sym_db.RegisterMessage(InterContainerRequestBody)

InterContainerResponseBody = _reflection.GeneratedProtocolMessageType('InterContainerResponseBody', (_message.Message,), {
  'DESCRIPTOR' : _INTERCONTAINERRESPONSEBODY,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterContainerResponseBody)
  })
_sym_db.RegisterMessage(InterContainerResponseBody)

SwitchCapability = _reflection.GeneratedProtocolMessageType('SwitchCapability', (_message.Message,), {
  'DESCRIPTOR' : _SWITCHCAPABILITY,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.SwitchCapability)
  })
_sym_db.RegisterMessage(SwitchCapability)

DeviceDiscovered = _reflection.GeneratedProtocolMessageType('DeviceDiscovered', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEDISCOVERED,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.DeviceDiscovered)
  })
_sym_db.RegisterMessage(DeviceDiscovered)

InterAdapterMessageType = _reflection.GeneratedProtocolMessageType('InterAdapterMessageType', (_message.Message,), {
  'DESCRIPTOR' : _INTERADAPTERMESSAGETYPE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterAdapterMessageType)
  })
_sym_db.RegisterMessage(InterAdapterMessageType)

InterAdapterHeader = _reflection.GeneratedProtocolMessageType('InterAdapterHeader', (_message.Message,), {
  'DESCRIPTOR' : _INTERADAPTERHEADER,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterAdapterHeader)
  })
_sym_db.RegisterMessage(InterAdapterHeader)

InterAdapterOmciMessage = _reflection.GeneratedProtocolMessageType('InterAdapterOmciMessage', (_message.Message,), {
  'DESCRIPTOR' : _INTERADAPTEROMCIMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterAdapterOmciMessage)
  })
_sym_db.RegisterMessage(InterAdapterOmciMessage)

InterAdapterTechProfileDownloadMessage = _reflection.GeneratedProtocolMessageType('InterAdapterTechProfileDownloadMessage', (_message.Message,), {
  'DESCRIPTOR' : _INTERADAPTERTECHPROFILEDOWNLOADMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterAdapterTechProfileDownloadMessage)
  })
_sym_db.RegisterMessage(InterAdapterTechProfileDownloadMessage)

InterAdapterDeleteGemPortMessage = _reflection.GeneratedProtocolMessageType('InterAdapterDeleteGemPortMessage', (_message.Message,), {
  'DESCRIPTOR' : _INTERADAPTERDELETEGEMPORTMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterAdapterDeleteGemPortMessage)
  })
_sym_db.RegisterMessage(InterAdapterDeleteGemPortMessage)

InterAdapterDeleteTcontMessage = _reflection.GeneratedProtocolMessageType('InterAdapterDeleteTcontMessage', (_message.Message,), {
  'DESCRIPTOR' : _INTERADAPTERDELETETCONTMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterAdapterDeleteTcontMessage)
  })
_sym_db.RegisterMessage(InterAdapterDeleteTcontMessage)

InterAdapterResponseBody = _reflection.GeneratedProtocolMessageType('InterAdapterResponseBody', (_message.Message,), {
  'DESCRIPTOR' : _INTERADAPTERRESPONSEBODY,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterAdapterResponseBody)
  })
_sym_db.RegisterMessage(InterAdapterResponseBody)

InterAdapterMessage = _reflection.GeneratedProtocolMessageType('InterAdapterMessage', (_message.Message,), {
  'DESCRIPTOR' : _INTERADAPTERMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterAdapterMessage)
  })
_sym_db.RegisterMessage(InterAdapterMessage)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/omci_mib_db.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import meta_pb2 as voltha__protos_dot_meta__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/omci_mib_db.proto',
  package='omci',
  syntax='proto3',
  serialized_options=b'\n\030org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v3/go/omci',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fvoltha_protos/omci_mib_db.proto\x12\x04omci\x1a\x18voltha_protos/meta.proto\"6\n\x10MibAttributeData\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\r\n\x05value\x18\x02 \x01(\t\"\x89\x01\n\x0fMibInstanceData\x12\x1a\n\x0binstance_id\x18\x01 \x01(\rB\x05\xe8\xf6\xcd\x1d\x01\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\x10\n\x08modified\x18\x03 \x01(\t\x12\x37\n\nattributes\x18\x04 \x03(\x0b\x32\x16.omci.MibAttributeDataB\x0b\xe2\xf6\xcd\x1d\x06\n\x04name\"e\n\x0cMibClassData\x12\x17\n\x08\x63lass_id\x18\x01 \x01(\rB\x05\xe8\xf6\xcd\x1d\x01\x12<\n\tinstances\x18\x02 \x03(\x0b\x32\x15.omci.MibInstanceDataB\x12\xe2\xf6\xcd\x1d\r\n\x0binstance_id\"=\n\rManagedEntity\x12\x17\n\x08\x63lass_id\x18\x01 \x01(\rB\x05\xe8\xf6\xcd\x1d\x01\x12\x13\n\x04name\x18\x02 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\"*\n\x0bMessageType\x12\x1b\n\x0cmessage_type\x18\x01 \x01(\rB\x05\xe8\xf6\xcd\x1d\x01\"\x89\x02\n\rMibDeviceData\x12\x18\n\tdevice_id\x18\x01 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\x16\n\x0elast_sync_time\x18\x03 \x01(\t\x12\x15\n\rmib_data_sync\x18\x04 \x01(\r\x12\x0f\n\x07version\x18\x05 \x01(\r\x12\x34\n\x07\x63lasses\x18\x06 \x03(\x0b\x32\x12.omci.MibClassDataB\x0f\xe2\xf6\xcd\x1d\n\n\x08\x63lass_id\x12-\n\x10managed_entities\x18\x07 \x03(\x0b\x32\x13.omci.ManagedEntity\x12(\n\rmessage_types\x18\x08 \x03(\x0b\x32\x11.omci.MessageType\".\n\x11OpenOmciEventType\"\x19\n\x05Types\x12\x10\n\x0cstate_change\x10\x00\"J\n\rOpenOmciEvent\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.omci.OpenOmciEventType.Types\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\tBH\n\x18org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v3/go/omcib\x06proto3'
  ,
  dependencies=[voltha__protos_dot_meta__pb2.DESCRIPTOR,])



_OPENOMCIEVENTTYPE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='omci.OpenOmciEventType.Types',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='state_change', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=762,
  serialized_end=787,
)
_sym_db.RegisterEnumDescriptor(_OPENOMCIEVENTTYPE_TYPES)


_MIBATTRIBUTEDATA = _descriptor.Descriptor(
  name='MibAttributeData',
  full_name='omci.MibAttributeData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='omci.MibAttributeData.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='omci.MibAttributeData.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=121,
)


_MIBINSTANCEDATA = _descriptor.Descriptor(
  name='MibInstanceData',
  full_name='omci.MibInstanceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='omci.MibInstanceData.instance_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='omci.MibInstanceData.created', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified', full_name='omci.MibInstanceData.modified', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='omci.MibInstanceData.attributes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\006\n\004name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=261,
)


_MIBCLASSDATA = _descriptor.Descriptor(
  name='MibClassData',
  full_name='omci.MibClassData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_id', full_name='omci.MibClassData.class_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instances', full_name='omci.MibClassData.instances', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\r\n\013instance_id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=364,
)


_MANAGEDENTITY = _descriptor.Descriptor(
  name='ManagedEntity',
  full_name='omci.ManagedEntity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_id', full_name='omci.ManagedEntity.class_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='omci.ManagedEntity.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=427,
)


_MESSAGETYPE = _descriptor.Descriptor(
  name='MessageType',
  full_name='omci.MessageType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_type', full_name='omci.MessageType.message_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=429,
  serialized_end=471,
)


_MIBDEVICEDATA = _descriptor.Descriptor(
  name='MibDeviceData',
  full_name='omci.MibDeviceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='omci.MibDeviceData.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='omci.MibDeviceData.created', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_sync_time', full_name='omci.MibDeviceData.last_sync_time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mib_data_sync', full_name='omci.MibDeviceData.mib_data_sync', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='omci.MibDeviceData.version', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classes', full_name='omci.MibDeviceData.classes', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\n\n\010class_id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='managed_entities', full_name='omci.MibDeviceData.managed_entities', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_types', full_name='omci.MibDeviceData.message_types', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=739,
)


_OPENOMCIEVENTTYPE = _descriptor.Descriptor(
  name='OpenOmciEventType',
  full_name='omci.OpenOmciEventType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPENOMCIEVENTTYPE_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=787,
)


_OPENOMCIEVENT = _descriptor.Descriptor(
  name='OpenOmciEvent',
  full_name='omci.OpenOmciEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='omci.OpenOmciEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='omci.OpenOmciEvent.data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=789,
  serialized_end=863,
)

_MIBINSTANCEDATA.fields_by_name['attributes'].message_type = _MIBATTRIBUTEDATA
_MIBCLASSDATA.fields_by_name['instances'].message_type = _MIBINSTANCEDATA
_MIBDEVICEDATA.fields_by_name['classes'].message_type = _MIBCLASSDATA
_MIBDEVICEDATA.fields_by_name['managed_entities'].message_type = _MANAGEDENTITY
_MIBDEVICEDATA.fields_by_name['message_types'].message_type = _MESSAGETYPE
_OPENOMCIEVENTTYPE_TYPES.containing_type = _OPENOMCIEVENTTYPE
_OPENOMCIEVENT.fields_by_name['type'].enum_type = _OPENOMCIEVENTTYPE_TYPES
DESCRIPTOR.message_types_by_name['MibAttributeData'] = _MIBATTRIBUTEDATA
DESCRIPTOR.message_types_by_name['MibInstanceData'] = _MIBINSTANCEDATA
DESCRIPTOR.message_types_by_name['MibClassData'] = _MIBCLASSDATA
DESCRIPTOR.message_types_by_name['ManagedEntity'] = _MANAGEDENTITY
DESCRIPTOR.message_types_by_name['MessageType'] = _MESSAGETYPE
DESCRIPTOR.message_types_by_name['MibDeviceData'] = _MIBDEVICEDATA
DESCRIPTOR.message_types_by_name['OpenOmciEventType'] = _OPENOMCIEVENTTYPE
DESCRIPTOR.message_types_by_name['OpenOmciEvent'] = _OPENOMCIEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MibAttributeData = _reflection.GeneratedProtocolMessageType('MibAttributeData', (_message.Message,), {
  'DESCRIPTOR' : _MIBATTRIBUTEDATA,
  '__module__' : 'voltha_protos.omci_mib_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.MibAttributeData)
  })
_sym_db.RegisterMessage(MibAttributeData)

MibInstanceData = _reflection.GeneratedProtocolMessageType('MibInstanceData', (_message.Message,), {
  'DESCRIPTOR' : _MIBINSTANCEDATA,
  '__module__' : 'voltha_protos.omci_mib_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.MibInstanceData)
  })
_sym_db.RegisterMessage(MibInstanceData)

MibClassData = _reflection.GeneratedProtocolMessageType('MibClassData', (_message.Message,), {
  'DESCRIPTOR' : _MIBCLASSDATA,
  '__module__' : 'voltha_protos.omci_mib_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.MibClassData)
  })
_sym_db.RegisterMessage(MibClassData)

ManagedEntity = _reflection.GeneratedProtocolMessageType('ManagedEntity', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDENTITY,
  '__module__' : 'voltha_protos.omci_mib_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.ManagedEntity)
  })
_sym_db.RegisterMessage(ManagedEntity)

MessageType = _reflection.GeneratedProtocolMessageType('MessageType', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGETYPE,
  '__module__' : 'voltha_protos.omci_mib_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.MessageType)
  })
_sym_db.RegisterMessage(MessageType)

MibDeviceData = _reflection.GeneratedProtocolMessageType('MibDeviceData', (_message.Message,), {
  'DESCRIPTOR' : _MIBDEVICEDATA,
  '__module__' : 'voltha_protos.omci_mib_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.MibDeviceData)
  })
_sym_db.RegisterMessage(MibDeviceData)

OpenOmciEventType = _reflection.GeneratedProtocolMessageType('OpenOmciEventType', (_message.Message,), {
  'DESCRIPTOR' : _OPENOMCIEVENTTYPE,
  '__module__' : 'voltha_protos.omci_mib_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.OpenOmciEventType)
  })
_sym_db.RegisterMessage(OpenOmciEventType)

OpenOmciEvent = _reflection.GeneratedProtocolMessageType('OpenOmciEvent', (_message.Message,), {
  'DESCRIPTOR' : _OPENOMCIEVENT,
  '__module__' : 'voltha_protos.omci_mib_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.OpenOmciEvent)
  })
_sym_db.RegisterMessage(OpenOmciEvent)


DESCRIPTOR._options = None
_MIBATTRIBUTEDATA.fields_by_name['name']._options = None
_MIBINSTANCEDATA.fields_by_name['instance_id']._options = None
_MIBINSTANCEDATA.fields_by_name['attributes']._options = None
_MIBCLASSDATA.fields_by_name['class_id']._options = None
_MIBCLASSDATA.fields_by_name['instances']._options = None
_MANAGEDENTITY.fields_by_name['class_id']._options = None
_MANAGEDENTITY.fields_by_name['name']._options = None
_MESSAGETYPE.fields_by_name['message_type']._options = None
_MIBDEVICEDATA.fields_by_name['device_id']._options = None
_MIBDEVICEDATA.fields_by_name['classes']._options = None
# @@protoc_insertion_point(module_scope)
